summaryrefslogtreecommitdiffstats
path: root/src/kqtempfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kqtempfile.h')
-rw-r--r--src/kqtempfile.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/kqtempfile.h b/src/kqtempfile.h
index 6440067..dda9f56 100644
--- a/src/kqtempfile.h
+++ b/src/kqtempfile.h
@@ -19,35 +19,35 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#ifndef KQTEMPFILE_H
-#define KQTEMPFILE_H
+#ifndef KTQTEMPFILE_H
+#define KTQTEMPFILE_H
-#include <qvaluevector.h>
-#include <qfile.h>
+#include <tqvaluevector.h>
+#include <tqfile.h>
/*
* This class generates temp file names in race condition-safe way,
* returns QFile and filename pairs, keeps the track of opened temp files,
* and deletes them when program exist.
*/
-class KQTempFileKeeper
+class KTQTempFileKeeper
{
public:
- KQTempFileKeeper();
- ~KQTempFileKeeper();
+ KTQTempFileKeeper();
+ ~KTQTempFileKeeper();
//! Generates a temporary file name, and creates it on disk at the same time.
//! Returns the file. If tempdir is not empty, it is used as temp directory.
- bool generateTempFile( QFile& file, const QString& tempdir = QString::null );
+ bool generateTempFile( TQFile& file, const TQString& tempdir = TQString() );
//! Closes and removes all the files from disk
void destroyTempFiles();
private:
- QValueVector<QString> m_tempFiles;
- QString m_tempDir;
+ TQValueVector<TQString> m_tempFiles;
+ TQString m_tempDir;
unsigned int m_fileNumber;
};
-#endif /* KQTEMPFILE_H */
+#endif /* KTQTEMPFILE_H */
@@ -19,35 +19,35 @@
/*
* This class generates temp file names in race condition-safe way,
- * returns QFile and filename pairs, keeps the track of opened temp files,
+ * returns TQFile and filename pairs, keeps the track of opened temp files,
* and deletes them when program exist.
*/